@@ -12,7 +12,7 @@ use feature ();
 package MooX::Pression;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.015';
+our $VERSION   = '0.016';
 
 use Keyword::Declare;
 use B::Hooks::EndOfScope;
@@ -637,6 +637,9 @@ sub _handle_has_keyword {
 		$rawspec = "default => sub { $default }, $rawspec";
 	}
 	
+	$name =~ s/^\+\*/+/;
+	$name =~ s/^\*//;
+	
 	sprintf(
 		'q[%s]->_has(scalar(%s), %s)',
 		$me,
@@ -833,11 +836,11 @@ sub import {
 	
 	# `has` keyword
 	#
-	keyword has ('+'? $plus, /[\$\@\%]/? $sigil, Identifier $name, '!'? $postfix) {
-		$me->_handle_has_keyword("$plus$sigil$name$postfix", undef, undef);
+	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix) {
+		$me->_handle_has_keyword("$plus$name$postfix", undef, undef);
 	}
-	keyword has ('+'? $plus, /[\$\@\%]/? $sigil, Identifier $name, '!'? $postfix, '(', List $spec, ')') {
-		$me->_handle_has_keyword("$plus$sigil$name$postfix", $spec, undef);
+	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix, '(', List $spec, ')') {
+		$me->_handle_has_keyword("$plus$name$postfix", $spec, undef);
 	}
 	keyword has (Block $name, '(', List $spec, ')') {
 		$me->_handle_has_keyword($name, $spec, undef);
@@ -845,11 +848,11 @@ sub import {
 	keyword has (Block $name) {
 		$me->_handle_has_keyword($name, undef, undef);
 	}
-	keyword has ('+'? $plus, /[\$\@\%]/? $sigil, Identifier $name, '!'? $postfix, '=', ListElem $default) {
-		$me->_handle_has_keyword("$plus$sigil$name$postfix", undef, $default);
+	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix, '=', ListElem $default) {
+		$me->_handle_has_keyword("$plus$name$postfix", undef, $default);
 	}
-	keyword has ('+'? $plus, /[\$\@\%]/? $sigil, Identifier $name, '!'? $postfix, '(', List $spec, ')', '=', ListElem $default) {
-		$me->_handle_has_keyword("$plus$sigil$name$postfix", $spec, $default);
+	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix, '(', List $spec, ')', '=', ListElem $default) {
+		$me->_handle_has_keyword("$plus$name$postfix", $spec, $default);
 	}
 	keyword has (Block $name, '(', List $spec, ')', '=', ListElem $default) {
 		$me->_handle_has_keyword($name, $spec, $default);
@@ -1070,7 +1073,7 @@ sub _modifier {
 #{
 #	package MooX::Pression::Anonymous::Package;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.015';
+#	our $VERSION   = '0.016';
 #	use overload q[""] => sub { ${$_[0]} }, fallback => 1;
 #	sub DESTROY {}
 #	sub AUTOLOAD {
@@ -1081,7 +1084,7 @@ sub _modifier {
 #	
 #	package MooX::Pression::Anonymous::Class;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.015';
+#	our $VERSION   = '0.016';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub new {
 #		my $me = shift;
@@ -1094,12 +1097,12 @@ sub _modifier {
 #	
 #	package MooX::Pression::Anonymous::Role;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.015';
+#	our $VERSION   = '0.016';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	
 #	package MooX::Pression::Anonymous::ParameterizableClass;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.015';
+#	our $VERSION   = '0.016';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -1113,7 +1116,7 @@ sub _modifier {
 #
 #	package MooX::Pression::Anonymous::ParameterizableRole;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.015';
+#	our $VERSION   = '0.016';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -1752,22 +1755,12 @@ values. For example:
     }
   }
 
-It is possible to add hints to the attribute name as a shortcut for common
-specifications.
+A trailing C<< ! >> indicates a required attribute.
 
   class Person {
-    has $name!;
-    has $age;
-    has @kids;
+    has name!;
   }
 
-Using C<< $ >>, C<< @ >> and C<< % >> sigils hints that the values should
-be a scalar, an arrayref, or a hashref (and tries to be smart about
-overloading). It I<< does not make the attribute available as a lexical >>!
-You still access the value as C<< $self->age >> and not just C<< $age >>.
-
-The trailing C<< ! >> indicates a required attribute.
-
 It is possible to give a default using an equals sign.
 
   class WidgetCollection {
@@ -1831,7 +1824,7 @@ name with a block that returns the name as a string.
 This can be used to define a bunch of types from a list.
 
   class Person {
-    my @attrs = qw( $name $age );
+    my @attrs = qw( name age );
     for my $attr (@attrs) {
       has {$attr} ( required => true );
     }
@@ -1842,6 +1835,14 @@ You can think of the syntax as being kind of like C<print>.
   print BAREWORD_FILEHANDLE @strings;
   print { block_returning_filehandle(); } @strings;
 
+The names of attributes can start with an asterisk:
+
+  has *foo;
+
+This adds no extra meaning, but is supported for consistency with the syntax
+of named parameters in method signatures. (Depending on your text editor, it
+may also improve syntax highlighting.)
+
 =head3 C<< constant >>
 
   class Person {
@@ -1855,7 +1856,7 @@ C<< $person_object->latin_name >> will return 'Homo sapiens'.
 =head3 C<< method >>
 
   class Person {
-    has $spouse;
+    has spouse;
     
     method marry {
       my ($self, $partner) = @_;
@@ -1892,7 +1893,7 @@ the body of the method.
 =head4 Signatures for Named Arguments
 
   class Person {
-    has $spouse;
+    has spouse;
     
     method marry ( Person *partner, Object *date = DateTime->now ) {
       $self->spouse( $arg->partner );
@@ -2234,7 +2235,7 @@ just one object in a factory method.
   class Wheel;
   
   class Car {
-    has @wheels;
+    has wheels = [];
     
     factory new_three_wheeler () {
       return $class->new(
@@ -2371,7 +2372,7 @@ The C<< :optimize >> attribute is not currently supported for C<coerce>.
 =head3 C<< overload >>
 
   class Collection {
-    has @items;
+    has items = [];
     overload '@{}' => sub { shift->list };
   }
 
